@@ -10,8 +10,10 @@ from .commit_transaction import *
 from .explain import *
 from .alter_table import *
 from .insert import *
+from .update import *
 from .delete import *
 from .drop import *
+from .create import *
 
 from mindsdb_sql.parser.dialects.mysql.variable import Variable
 from mindsdb_sql.parser.dialects.mindsdb.latest import Latest
